==> mo_a5_plugin-0.0.1.tar.gz: android/src/main/java/in/mobiocean/mo_a5_plugin/MoA5Plugin.java <==
package in.mobiocean.mo_a5_plugin;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Message;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.telpo.tps550.api.TelpoException;
import com.telpo.tps550.api.nfc.Nfc;
import com.telpo.tps550.api.printer.UsbThermalPrinter;
import com.telpo.tps550.api.util.StringUtil;
import com.telpo.tps550.api.util.SystemUtil;

/** MoA5Plugin */
public class MoA5Plugin implements FlutterPlugin, MethodCallHandler, ActivityAware, ReadCallback {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private UsbThermalPrinter mUsbThermalPrinter;

  private final int NOPAPER = 3;
  private final int PRINTCONTENT = 9;
  private final int LOWPOWER = 10;
  private final int PRINTERR = 11;
  private final int OVERHEAT = 12;

  private MyHandler handler;
  private String printContent = null;
  private Bitmap bitmap = null;
  private Result printerResult;

  private Activity activity;
  private Context context;
  private NfcSample nfcSample;
  private Result readResult;

  private class MyHandler extends Handler {
    @Override
    public void handleMessage(Message msg) {
      switch (msg.what) {
        case LOWPOWER:
          if (printerResult != null) printerResult.success("-1");
          break;
        case NOPAPER:
          if (printerResult != null) printerResult.success("-2");
          break;
        case PRINTCONTENT:
          new contentPrintThread().start();
          break;
        case OVERHEAT:
          if (printerResult != null) printerResult.success("-3");
          break;
        default:
          if (printerResult != null) printerResult.success("-1");
          break;
      }
    }
  }

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mo_a5_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onAttachedToActivity(ActivityPluginBinding binding){
    activity = binding.getActivity();
    context = binding.getActivity();
    nfcSample = new NfcSample(activity, this);
    mUsbThermalPrinter = new UsbThermalPrinter(context);
    handler = new MyHandler();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding){
    activity = binding.getActivity();
    context = binding.getActivity();
    if(nfcSample == null)
      nfcSample = new NfcSample(activity, this);
    else
      nfcSample.updateCallBack(this);
    mUsbThermalPrinter = new UsbThermalPrinter(context);
    handler = new MyHandler();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    readResult = null;
    printerResult = null;
    if (call.method.equals("startNfc")) {
      int res = nfcSample.startNfc();
      result.success(""+res);
    } else if (call.method.equals("closeNfc")) {
      int res = nfcSample.closeNfc();
      result.success(""+res);
    } else if (call.method.equals("readCard")) {
      readResult = result;
      nfcSample.readCard();
    } else if (call.method.equals("haltOperation")) {
      int res = nfcSample.m1HaltOperation();
      result.success(""+res);
    } else if (call.method.equals("authBlock")) {
      byte blockNo = call.argument("blockNo");
      byte[] password = call.argument("password");
      int res = nfcSample.m1CardAuthenticate(blockNo, password);
      result.success(""+res);
    } else if (call.method.equals("readBlock")) {
      byte blockNo = call.argument("blockNo");
      String res = nfcSample.readValueData(blockNo);
      result.success(""+res);
    } else if (call.method.equals("writeBlock")) {
      byte blockNo = call.argument("blockNo");
      String conent = call.argument("conent");
      int res = nfcSample.writeValueData(blockNo, conent);
      result.success(""+res);
    } else if (call.method.equals("printContent")) {
      this.printerResult = result;
      printContent = call.argument("content");
      handler.sendMessage(handler.obtainMessage(PRINTCONTENT, 1, 0, null));
    } else if (call.method.equals("printImage")) {
      this.printerResult = result;
      bitmap = call.argument("imageContent");
      handler.sendMessage(handler.obtainMessage(PRINTCONTENT, 1, 0, null));
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    context = null;
    activity = null;
    readResult = null;
    printerResult = null;
  }

  @Override
  public void onDetachedFromActivity() {
    context = null;
    activity = null;
    readResult = null;
    printerResult = null;
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
    readResult = null;
  }

  @Override
  public void timeout() {
    if(readResult != null)
      readResult.success("-1");
  }

  @Override
  public void unknownCard() {
    if(readResult != null)
      readResult.success("-2");
  }

  @Override
  public void cardRead(String atqa, String sak, String uid) {
    if(readResult != null)
      readResult.success("{" +
              "\"atqa\":\"" + atqa + "\"" +
              "\"sak\":\"" + sak + "\"" +
              "\"uid\":\"" + uid + "\"" +
              "}");
  }

  @Override
  public void readFailure(Exception e) {
    if(readResult != null)
      readResult.success("-3");
  }

  private class contentPrintThread extends Thread {
    @Override
    public void run() {
      super.run();
      try {
        mUsbThermalPrinter.start(1);
        mUsbThermalPrinter.reset();
        mUsbThermalPrinter.setMonoSpace(true);
        mUsbThermalPrinter.setAlgin(UsbThermalPrinter.ALGIN_MIDDLE);
        mUsbThermalPrinter.setLeftIndent(0);
        mUsbThermalPrinter.setLineSpace(0);
        mUsbThermalPrinter.setTextSize(20);
        mUsbThermalPrinter.setGray(7);
        if(printContent != null) {
          mUsbThermalPrinter.addString(printContent);
          mUsbThermalPrinter.printString();
        }
        if(bitmap != null){
          mUsbThermalPrinter.printLogo(bitmap, false);
        }
        mUsbThermalPrinter.walkPaper(10);
        mUsbThermalPrinter.reset();
        if (printerResult != null)
          printerResult.success("0");
      } catch (TelpoException e) {
        e.printStackTrace();
        String Result = e.toString();
        if (Result.equals("com.telpo.tps550.api.printer.NoPaperException")) {
          handler.sendMessage(handler.obtainMessage(NOPAPER, 1, 0, null));
        } else if (Result.equals("com.telpo.tps550.api.printer.OverHeatException")) {
          handler.sendMessage(handler.obtainMessage(OVERHEAT, 1, 0, null));
        } else if (Result.equals("com.telpo.tps550.api.printer.LowPowerException")) {
          handler.sendMessage(handler.obtainMessage(LOWPOWER, 1, 0, null));
        } else {
          handler.sendMessage(handler.obtainMessage(PRINTERR, 1, 0, null));
        }
      }
    }
  }
}

==> mo_a5_plugin-0.0.2.tar.gz: android/src/main/java/in/mobiocean/mo_a5_plugin/MoA5Plugin.java <==
package in.mobiocean.mo_a5_plugin;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Message;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.telpo.tps550.api.TelpoException;
import com.telpo.tps550.api.nfc.Nfc;
import com.telpo.tps550.api.printer.UsbThermalPrinter;
import com.telpo.tps550.api.util.StringUtil;
import com.telpo.tps550.api.util.SystemUtil;

/** MoA5Plugin */
public class MoA5Plugin implements FlutterPlugin, MethodCallHandler, ActivityAware, ReadCallback {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private UsbThermalPrinter mUsbThermalPrinter;

  private final int NOPAPER = 3;
  private final int PRINTCONTENT = 9;
  private final int LOWPOWER = 10;
  private final int PRINTERR = 11;
  private final int OVERHEAT = 12;

  private MyHandler handler;
  private String printContent = null;
  private Bitmap bitmap = null;
  private Result printerResult;

  private Activity activity;
  private Context context;
  private NfcSample nfcSample;
  private Result readResult;

  private class MyHandler extends Handler {
    @Override
    public void handleMessage(Message msg) {
      switch (msg.what) {
        case LOWPOWER:
          if (printerResult != null) printerResult.success("-1");
          break;
        case NOPAPER:
          if (printerResult != null) printerResult.success("-2");
          break;
        case PRINTCONTENT:
          new contentPrintThread().start();
          break;
        case OVERHEAT:
          if (printerResult != null) printerResult.success("-3");
          break;
        default:
          if (printerResult != null) printerResult.success("-1");
          break;
      }
    }
  }

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mo_a5_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onAttachedToActivity(ActivityPluginBinding binding){
    activity = binding.getActivity();
    context = binding.getActivity();
    nfcSample = new NfcSample(activity, this);
    mUsbThermalPrinter = new UsbThermalPrinter(context);
    handler = new MyHandler();
  }

  @Override
  public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding){
    activity = binding.getActivity();
    context = binding.getActivity();
    if(nfcSample == null)
      nfcSample = new NfcSample(activity, this);
    else
      nfcSample.updateCallBack(this);
    mUsbThermalPrinter = new UsbThermalPrinter(context);
    handler = new MyHandler();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    readResult = null;
    printerResult = null;
    if (call.method.equals("startNfc")) {
      int res = nfcSample.startNfc();
      result.success(""+res);
    } else if (call.method.equals("closeNfc")) {
      int res = nfcSample.closeNfc();
      result.success(""+res);
    } else if (call.method.equals("readCard")) {
      readResult = result;
      nfcSample.readCard();
    } else if (call.method.equals("haltOperation")) {
      int res = nfcSample.m1HaltOperation();
      result.success(""+res);
    } else if (call.method.equals("authBlock")) {
      byte blockNo = call.argument("blockNo");
      int[] password = call.argument("password");
      int res = nfcSample.m1CardAuthenticate(blockNo, password);
      result.success(""+res);
    } else if (call.method.equals("readBlock")) {
      byte blockNo = call.argument("blockNo");
      String res = nfcSample.readValueData(blockNo);
      result.success(""+res);
    } else if (call.method.equals("writeBlock")) {
      byte blockNo = call.argument("blockNo");
      String conent = call.argument("conent");
      int res = nfcSample.writeValueData(blockNo, conent);
      result.success(""+res);
    } else if (call.method.equals("printContent")) {
      this.printerResult = result;
      printContent = call.argument("content");
      handler.sendMessage(handler.obtainMessage(PRINTCONTENT, 1, 0, null));
    } else if (call.method.equals("printImage")) {
      this.printerResult = result;
      bitmap = call.argument("imageContent");
      handler.sendMessage(handler.obtainMessage(PRINTCONTENT, 1, 0, null));
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {
    context = null;
    activity = null;
    readResult = null;
    printerResult = null;
  }

  @Override
  public void onDetachedFromActivity() {
    context = null;
    activity = null;
    readResult = null;
    printerResult = null;
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
    readResult = null;
  }

  @Override
  public void timeout() {
    if(readResult != null)
      readResult.success("-1");
  }

  @Override
  public void unknownCard() {
    if(readResult != null)
      readResult.success("-2");
  }

  @Override
  public void cardRead(String atqa, String sak, String uid) {
    if(readResult != null)
      readResult.success("{" +
              "\"atqa\":\"" + atqa + "\"" +
              "\"sak\":\"" + sak + "\"" +
              "\"uid\":\"" + uid + "\"" +
              "}");
  }

  @Override
  public void readFailure(Exception e) {
    if(readResult != null)
      readResult.success("-3");
  }

  private class contentPrintThread extends Thread {
    @Override
    public void run() {
      super.run();
      try {
        mUsbThermalPrinter.start(1);
        mUsbThermalPrinter.reset();
        mUsbThermalPrinter.setMonoSpace(true);
        mUsbThermalPrinter.setAlgin(UsbThermalPrinter.ALGIN_MIDDLE);
        mUsbThermalPrinter.setLeftIndent(0);
        mUsbThermalPrinter.setLineSpace(0);
        mUsbThermalPrinter.setTextSize(20);
        mUsbThermalPrinter.setGray(7);
        if(printContent != null) {
          mUsbThermalPrinter.addString(printContent);
          mUsbThermalPrinter.printString();
        }
        if(bitmap != null){
          mUsbThermalPrinter.printLogo(bitmap, false);
        }
        mUsbThermalPrinter.walkPaper(10);
        mUsbThermalPrinter.reset();
        if (printerResult != null)
          printerResult.success("0");
      } catch (TelpoException e) {
        e.printStackTrace();
        String Result = e.toString();
        if (Result.equals("com.telpo.tps550.api.printer.NoPaperException")) {
          handler.sendMessage(handler.obtainMessage(NOPAPER, 1, 0, null));
        } else if (Result.equals("com.telpo.tps550.api.printer.OverHeatException")) {
          handler.sendMessage(handler.obtainMessage(OVERHEAT, 1, 0, null));
        } else if (Result.equals("com.telpo.tps550.api.printer.LowPowerException")) {
          handler.sendMessage(handler.obtainMessage(LOWPOWER, 1, 0, null));
        } else {
          handler.sendMessage(handler.obtainMessage(PRINTERR, 1, 0, null));
        }
      }
    }
  }
}
